/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */

/*
 *  Copyright (C) 2003 Takuro Ashie
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2, or (at your option)
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 *  $Id: kz-actions-bookmark.h,v 1.3 2004/07/05 09:17:10 ikezoe Exp $
 */

/*
 *  Global actions for bookmark editor window.
 */

#ifndef __KZ_ACTIONS_BOOKMARK_H__
#define __KZ_ACTIONS_BOOKMARK_H__

#ifdef HAVE_CONFIG_H
#	include "config.h"
#endif /* HAVE_CONFIG_H */

#include <glib.h>
#include "gtk24backports.h"
#include "kz-bookmark-editor.h"

G_BEGIN_DECLS

GtkActionGroup *kz_actions_bookmark_create_group (KzBookmarkEditor *editor,
						  GtkAccelGroup *accel_group);

void kz_actions_bookmark_popup_menu_modal (KzBookmarkEditor *editor,
					   guint button, guint time);

G_END_DECLS

#endif /* __KZ_ACTIONS_BOOKMARK_H__ */
